summaryrefslogtreecommitdiffstats
path: root/parts/classview/classtooldlg.h
diff options
context:
space:
mode:
Diffstat (limited to 'parts/classview/classtooldlg.h')
-rw-r--r--parts/classview/classtooldlg.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/parts/classview/classtooldlg.h b/parts/classview/classtooldlg.h
index 9b722346..2ad80a58 100644
--- a/parts/classview/classtooldlg.h
+++ b/parts/classview/classtooldlg.h
@@ -47,7 +47,7 @@ public slots:
void viewNone();
/** View the parents of the current class. */
void viewParents();
/** View the tqchildren of the current class. */
void viewChildren();
/** View all classes that has this class as an attribute. */
void viewClients();
@@ -76,7 +76,7 @@ private:
TQComboBox *class_combo;
TQToolButton *parents_button;
- TQToolButton *tqchildren_button;
+ TQToolButton *children_button;
TQToolButton *clients_button;
TQToolButton *suppliers_button;
TQToolButton *methods_button;
@@ -47,7 +47,7 @@ public slots:
/** View the parents of the current class. */
void viewParents();
- /** View the tqchildren of the current class. */
+ /** View the children of the current class. */
void viewChildren();
/** View all classes that has this class as an attribute. */